aboutsummaryrefslogtreecommitdiff
path: root/src/backend/utils/activity/backend_progress.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/backend/utils/activity/backend_progress.c')
-rw-r--r--src/backend/utils/activity/backend_progress.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/backend/utils/activity/backend_progress.c b/src/backend/utils/activity/backend_progress.c
index bfb9b7704b1..c78c5eb5076 100644
--- a/src/backend/utils/activity/backend_progress.c
+++ b/src/backend/utils/activity/backend_progress.c
@@ -92,7 +92,7 @@ void
pgstat_progress_parallel_incr_param(int index, int64 incr)
{
/*
* Parallel workers notify a leader through a 'P' protocol message to
* update progress, passing the progress index and incremented value.
* Leaders can just call pgstat_progress_incr_param directly.
*/
@@ -102,7 +102,7 @@ pgstat_progress_parallel_incr_param(int index, int64 incr)
initStringInfo(&progress_message);
- pq_beginmessage(&progress_message, 'P');
+ pq_beginmessage(&progress_message, PqMsg_Progress);
pq_sendint32(&progress_message, index);
pq_sendint64(&progress_message, incr);
pq_endmessage(&progress_message);
@@ -92,7 +92,7 @@ void
{
/*
- * Parallel workers notify a leader through a 'P' protocol message to
+ * Parallel workers notify a leader through a PqMsg_Progress message to
* update progress, passing the progress index and incremented value.
* Leaders can just call pgstat_progress_incr_param directly.